package de.fitko.fitconnect.api.services.metadata;

import de.fitko.fitconnect.api.domain.model.metadata.Metadata;
import de.fitko.fitconnect.api.domain.model.metadata.attachment.Attachment;
import de.fitko.fitconnect.api.domain.model.metadata.data.Data;
import de.fitko.fitconnect.api.domain.model.submission.Submission;

import java.util.List;

/**
 * Provides the generation of correct and valid {@link Metadata} for a {@link Submission}
 *
 * @see
 * <a href="https://docs.fitko.de/fit-connect/docs/metadataoverview">Metadata</a> and
 * <a href="https://docs.fitko.de/fit-connect/docs/getting-started/submission/structure">Strcuture of a submission</a>
 */
public interface MetadataService {

    /**
     * Generates valid metadata for a submission including its JWE-encrypted data and attachments
     * and uploads it to the Fit-Connect API
     *
     * @param data the actual data payload (json or xml)
     * @param attachments list of 0..n attachments as binary data
     * @return Metadata with hashes of the data and attachments to send
     */
    Metadata createMetadata(final Data data, final List<Attachment> attachments);
}
